@@ -3,8 +3,8 @@ from distutils.log import error
 
 alphs = ['a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z']
 def renderText(string, writetime):
-        os.system('cls')
-        os.system('cls')
+        os.system('clear')
+        os.system('clear')
         for char in f"{string}\n":
                 sys.stdout.write(f"{char}")
                 sys.stdout.flush()
@@ -12,7 +12,7 @@ def renderText(string, writetime):
 
 def deleteText(wait):
         time.sleep(wait)
-        os.system('cls')
+        os.system('clear')
 
 def PythonRunner():
         for char in 'User@Desktop $ bash -f python.sh':
